@@ -1,3 +1,4 @@
+import os
 import json
 import multiprocessing
 from random import random
@@ -766,6 +767,15 @@ class Trainer():
         norm_class = nn.BatchNorm2d if not self.use_evonorm else lambda chans: EvoNorm2d(chans, groups = 32) if chans >= 64 else nn.Identity()
         norm_class = nn.SyncBatchNorm if not self.use_evonorm and self.syncbatchnorm else norm_class
 
+        # handle bugs when
+        # switching from multi-gpu back to single gpu
+
+        if self.syncbatchnorm and not self.is_ddp:
+            import torch.distributed as dist
+            os.environ['MASTER_ADDR'] = 'localhost'
+            os.environ['MASTER_PORT'] = '12355'
+            dist.init_process_group('nccl', rank=0, world_size=1)
+
         # instantiate GAN
 
         self.GAN = LightweightGAN(
@@ -839,8 +849,6 @@ class Trainer():
         aug_types  = self.aug_types
         aug_kwargs = {'prob': aug_prob, 'types': aug_types}
 
-        apply_ss_aux_loss = self.steps % 8 == 0
-
         G = self.GAN.G if not self.is_ddp else self.G_ddp
         D = self.GAN.D if not self.is_ddp else self.D_ddp
         D_aug = self.GAN.D_aug if not self.is_ddp else self.D_aug_ddp
@@ -857,7 +865,7 @@ class Trainer():
 
             image_batch = next(self.loader).cuda(self.rank)
             image_batch.requires_grad_()
-            real_output, real_aux_loss = D_aug(image_batch,  calc_aux_loss = apply_ss_aux_loss, **aug_kwargs)
+            real_output, real_aux_loss = D_aug(image_batch,  calc_aux_loss = True, **aug_kwargs)
 
             real_output_loss = real_output
             fake_output_loss = fake_output
